@@ -617,14 +617,8 @@ const LocalDocument = new Lang.Class({
     },
 
     updateTypeDescription: function() {
-        let description = '';
-
-        if (this.collection)
-            description = _("Collection");
-        else if (this.mimeType)
-            description = Gio.content_type_get_description(this.mimeType);
-
-        this.typeDescription = description;
+        if (this.mimeType)
+            this.typeDescription = Gio.content_type_get_description(this.mimeType);
     },
 
     load: function(cancellable, callback) {
@@ -746,10 +740,8 @@ const GoogleDocument = new Lang.Class({
 
                 let checksum = new GLib.Checksum(GLib.ChecksumType.MD5);
                 checksum.update(this.uri, -1);
-                let dirPath = GLib.build_filenamev([GLib.get_user_cache_dir(), "thumbnails", "normal"]);
-                GLib.mkdir_with_parents(dirPath, 0700);
                 let basename = checksum.get_string() + '.png';
-                let path = GLib.build_filenamev([dirPath, basename])
+                let path = GLib.build_filenamev([GLib.get_user_cache_dir(), "thumbnails", "normal", basename]);
 
                 let downloadFile = Gio.File.new_for_path(path);
                 downloadFile.replace_async
@@ -784,12 +776,12 @@ const GoogleDocument = new Lang.Class({
     updateTypeDescription: function() {
         let description;
 
-        if (this.collection)
-            description = _("Collection");
-        else if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
+        if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
+        else if (this.rdfType.indexOf('nfo#DataContainer') != -1)
+            description = _("Collection");
         else
             description = _("Document");
 
@@ -882,12 +874,12 @@ const SkydriveDocument = new Lang.Class({
     updateTypeDescription: function() {
         let description;
 
-        if (this.collection)
-            description = _("Collection");
-        else if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
+        if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
+        else if (this.rdfType.indexOf('nfo#DataContainer') != -1)
+            description = _("Collection");
         else
             description = _("Document");
 
@@ -990,7 +982,7 @@ const DocumentManager = new Lang.Class({
 
     clear: function() {
         let items = this.getItems();
-        for (idx in items) {
+        for (let idx in items) {
             items[idx].destroy();
         };
 
