@@ -75,6 +75,11 @@ const PreviewView = new Lang.Class({
 
         this._createView();
 
+        // create context menu
+        let model = this._getPreviewContextMenu();
+        this._previewContextMenu = Gtk.Menu.new_from_model(model);
+        this._previewContextMenu.attach_to_widget(this.widget, null);
+
         // create page nav bar
         this._navBar = new PreviewNavBar(this._model);
         this._overlay.add_overlay(this._navBar.widget);
@@ -113,6 +118,11 @@ const PreviewView = new Lang.Class({
             function() {
                 this.view.find_next();
             }));
+        this._copy = Application.application.lookup_action('copy');
+        this._copy.connect('activate', Lang.bind(this,
+            function() {
+                this.view.copy();
+            }));
 
         let rotLeft = Application.application.lookup_action('rotate-left');
         rotLeft.connect('activate', Lang.bind(this,
@@ -141,6 +151,7 @@ const PreviewView = new Lang.Class({
 
     _onLoadStarted: function() {
         this._showPlaces.enabled = false;
+        this._copy.enabled = false;
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
@@ -240,7 +251,9 @@ const PreviewView = new Lang.Class({
 
     _onViewSelectionChanged: function() {
         this._viewSelectionChanged = true;
-        if (!this.view.get_has_selection())
+        let has_selection = this.view.get_has_selection();
+        this._copy.enabled = has_selection;
+        if (!has_selection)
             this._cancelControlsFlip();
     },
 
@@ -329,6 +342,12 @@ const PreviewView = new Lang.Class({
             this._handleExternalLink));
     },
 
+    _getPreviewContextMenu: function() {
+        let builder = new Gtk.Builder();
+        builder.add_from_resource('/org/gnome/documents/preview-context-menu.ui');
+        return builder.get_object('preview-context-menu');
+    },
+
     _syncControlsVisible: function() {
         if (this._controlsVisible) {
             if (this._fsToolbar)
@@ -375,15 +394,18 @@ const PreviewView = new Lang.Class({
     _onKeyPressEvent: function(widget, event) {
         let keyval = event.get_keyval()[1];
         let state = event.get_state()[1];
+        let def_mod_mask = Gtk.accelerator_get_default_mod_mask();
 
-        if ((keyval == Gdk.KEY_Page_Up) &&
-            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) {
+        if (((keyval == Gdk.KEY_Page_Up) &&
+            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
+            ((keyval == Gdk.KEY_Left) && ((state & def_mod_mask) == 0))) {
             this.view.previous_page();
             return true;
         }
 
-        if ((keyval == Gdk.KEY_Page_Down) &&
-            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) {
+        if (((keyval == Gdk.KEY_Page_Down) &&
+            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
+            ((keyval == Gdk.KEY_Right) && ((state & def_mod_mask) == 0))) {
             this.view.next_page();
             return true;
         }
@@ -428,9 +450,15 @@ const PreviewView = new Lang.Class({
      },
 
     _onButtonPressEvent: function(widget, event) {
+        let button = event.get_button()[1];
+
+        if (button == 3) {
+            let time = event.get_time();
+            this._previewContextMenu.popup(null, null, null, button, time);
+            return true;
+        }
 
         this._viewSelectionChanged = false;
-
         return false;
    },
 
@@ -562,7 +590,8 @@ const PreviewNavBar = new Lang.Class({
         let button = new Gtk.Button({ action_name: 'app.places',
                                       child: new Gtk.Image({ icon_name: 'view-list-symbolic',
                                                              pixel_size: 16 }),
-                                      valign: Gtk.Align.CENTER
+                                      valign: Gtk.Align.CENTER,
+                                      tooltip_text: _("Bookmarks")
                                     });
         let buttonArea = this.widget.get_button_area();
         buttonArea.pack_start(button, false, false, 0);
@@ -570,7 +599,8 @@ const PreviewNavBar = new Lang.Class({
         button = new Gtk.ToggleButton({ action_name: 'app.bookmark-page',
                                         child: new Gtk.Image({ icon_name: 'bookmark-add-symbolic',
                                                                pixel_size: 16 }),
-                                        valign: Gtk.Align.CENTER
+                                        valign: Gtk.Align.CENTER,
+                                        tooltip_text: _("Bookmark this page")
                                       });
         buttonArea.pack_start(button, false, false, 0);
     },
@@ -829,9 +859,24 @@ const PreviewToolbar = new Lang.Class({
         this._searchAction.enabled = false;
     },
 
-    _onLoadFinished: function() {
+    _onLoadFinished: function(manager, doc, docModel) {
         this._gearMenu.enabled = true;
-        this._searchAction.enabled = true;
+
+        let evDoc = docModel.get_document();
+        let hasPages = (evDoc.get_n_pages() > 0);
+        let isFind = true;
+
+        try {
+            // This is a hack to find out if evDoc implements the
+            // EvDocument.DocumentFind interface or not. We don't expect
+            // the following invocation to work.
+            evDoc.find_text();
+        } catch (e if e instanceof TypeError) {
+            isFind = false;
+        } catch (e) {
+        }
+
+        this._searchAction.enabled = (hasPages && isFind);
     },
 
     _getPreviewMenu: function() {
@@ -957,7 +1002,7 @@ const PreviewFullscreenToolbar = new Lang.Class({
     _init: function(previewView) {
         this.parent(previewView);
 
-        this.revealer = new Gd.Revealer({ valign: Gtk.Align.START });
+        this.revealer = new Gtk.Revealer({ valign: Gtk.Align.START });
         this.revealer.add(this.widget);
         this.revealer.show();
 
