@@ -30,6 +30,7 @@ const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Tracker = imports.gi.Tracker;
 const _ = imports.gettext.gettext;
+const C_ = imports.gettext.pgettext;
 
 function initSearch(context) {
     context.collectionManager = new Manager.BaseManager(context);
@@ -163,7 +164,7 @@ const SearchTypeManager = new Lang.Class({
     _init: function(context) {
         // Translators: "Type" refers to a search filter on the document type
         // (PDF, spreadsheet, ...)
-        this.parent(_("Type"), context);
+        this.parent(C_("Search Filter", "Type"), context);
 
         this.addItem(new SearchType({ id: 'all',
                                       name: _("All") }));
@@ -254,10 +255,10 @@ const SearchMatchManager = new Lang.Class({
                                        name: _("All") }));
         this.addItem(new SearchMatch({ id: SearchMatchStock.TITLE,
         //Translators: "Title" refers to "Match Title" when searching
-                                       name: _("Title") }));
+                                       name: C_("Search Filter", "Title") }));
         this.addItem(new SearchMatch({ id: SearchMatchStock.AUTHOR,
         //Translators: "Author" refers to "Match Author" when searching
-                                       name: _("Author") }));
+                                       name: C_("Search Filter", "Author") }));
 
         this.setActiveItemById(SearchMatchStock.ALL);
     },
@@ -448,7 +449,7 @@ const SourceManager = new Lang.Class({
         let sources = this.getItems();
         let filters = [];
 
-        for (idx in sources) {
+        for (let idx in sources) {
             let source = sources[idx];
             if (!source.builtin)
                 filters.push(source.getFilter());
